@@ -11,7 +11,7 @@ if (isset($_GET["sqlite"])) {
 			public $extension = "SQLite3";
 			private $link;
 
-			function attach(?string $filename, string $username, string $password): string {
+			function attach(string $filename, string $username, string $password): string {
 				$this->link = new \SQLite3($filename);
 				$version = $this->link->version();
 				$this->server_info = $version["versionString"];
@@ -75,11 +75,8 @@ if (isset($_GET["sqlite"])) {
 		abstract class SqliteDb extends PdoDb {
 			public $extension = "PDO_SQLite";
 
-			function attach(?string $filename, string $username, string $password): string {
-				$this->dsn(DRIVER . ":$filename", "", "");
-				$this->query("PRAGMA foreign_keys = 1");
-				$this->query("PRAGMA busy_timeout = 500");
-				return '';
+			function attach(string $filename, string $username, string $password): string {
+				return $this->dsn(DRIVER . ":$filename", "", "");
 			}
 		}
 
@@ -87,7 +84,7 @@ if (isset($_GET["sqlite"])) {
 
 	if (class_exists('Adminer\SqliteDb')) {
 		class Db extends SqliteDb {
-			function attach(?string $filename, string $username, string $password): string {
+			function attach(string $filename, string $username, string $password): string {
 				parent::attach($filename, $username, $password);
 				$this->query("PRAGMA foreign_keys = 1");
 				$this->query("PRAGMA busy_timeout = 500");
@@ -122,7 +119,7 @@ if (isset($_GET["sqlite"])) {
 		public $functions = array("hex", "length", "lower", "round", "unixepoch", "upper");
 		public $grouping = array("avg", "count", "count distinct", "group_concat", "max", "min", "sum");
 
-		static function connect(?string $server, string $username, string $password) {
+		static function connect(string $server, string $username, string $password) {
 			if ($password != "") {
 				return lang('Database does not support password.');
 			}
@@ -452,7 +449,7 @@ if (isset($_GET["sqlite"])) {
 	* @param list<list<string>> $fields [process_field()], empty to preserve
 	* @param string[] $originals [$original => idf_escape($new_column)], empty to preserve
 	* @param string[] $foreign [format_foreign_key()], empty to preserve
-	* @param numeric-string $auto_increment set auto_increment to this value, "" to preserve
+	* @param numeric-string|'' $auto_increment set auto_increment to this value, "" to preserve
 	* @param list<array{string, string, list<string>|'DROP'}> $indexes [[$type, $name, $columns]], empty to preserve
 	* @param string $drop_check CHECK constraint to drop
 	* @param string $add_check CHECK constraint to add
@@ -680,7 +677,7 @@ if (isset($_GET["sqlite"])) {
 		return "DELETE FROM " . table($table);
 	}
 
-	function use_sql($database) {
+	function use_sql($database, $style = "") {
 	}
 
 	function trigger_sql($table) {
