@@ -85,6 +85,10 @@ class Adminer {
 		return 2;
 	}
 
+	/** Called after connecting and selecting a database */
+	function afterConnect(): void {
+	}
+
 	/** Headers to send before HTML output */
 	function headers(): void {
 	}
@@ -197,10 +201,10 @@ class Adminer {
 		$is_view = false;
 		if (support("table")) {
 			$is_view = is_view($tableStatus);
-			if ($is_view) {
-				$links["view"] = lang('Alter view');
-			} else {
+			if (!$is_view) {
 				$links["create"] = lang('Alter table');
+			} elseif (support("view")) {
+				$links["view"] = lang('Alter view');
 			}
 		}
 		if ($set !== null) {
@@ -300,7 +304,7 @@ class Adminer {
 			: (preg_match('~json~', $field["type"]) ? "<code class='jush-js'>$val</code>"
 			: $val)
 		));
-		if (preg_match('~blob|bytea|raw|file~', $field["type"]) && !is_utf8($val)) {
+		if (is_blob($field) && !is_utf8($val)) {
 			$return = "<i>" . lang('%d byte(s)', strlen($original)) . "</i>";
 		}
 		return ($link ? "<a href='" . h($link) . "'" . (is_url($link) ? target_blank() : "") . ">$return</a>" : $return);
@@ -664,7 +668,7 @@ class Adminer {
 		}
 		$history[$_GET["db"]][] = array($query, time(), $time); // not DB - $_GET["db"] is changed in database.inc.php //! respect $_GET["ns"]
 		$sql_id = "sql-" . count($history[$_GET["db"]]);
-		$return = "<a href='#$sql_id' class='toggle'>" . lang('SQL command') . "</a>\n";
+		$return = "<a href='#$sql_id' class='toggle'>" . lang('SQL command') . "</a> <a href='' class='jsonly copy'>🗐</a>\n";
 		if (!$failed && ($warnings = driver()->warnings())) {
 			$id = "warnings-" . count($history[$_GET["db"]]);
 			$return = "<a href='#$id' class='toggle'>" . lang('Warnings') . "</a>, $return<div id='$id' class='hidden'>\n$warnings</div>\n";
@@ -699,7 +703,7 @@ class Adminer {
 					}
 				}
 			}
-			if ($key && $functions && !preg_match('~set|blob|bytea|raw|file|bool~', $field["type"])) {
+			if ($key && $functions && !preg_match('~set|bool~', $field["type"]) && !is_blob($field)) {
 				$return .= "/SQL";
 			}
 		}
@@ -713,13 +717,13 @@ class Adminer {
 	* @param ?string $table null in call.inc.php
 	* @param Field $field
 	* @param string $attrs attributes to use inside the tag
+	* @param string|string[]|false|null $value false means original value
 	* @return string custom input field or empty string for default
 	*/
-	function editInput(?string $table, array $field, string $attrs, ?string $value): string {
+	function editInput(?string $table, array $field, string $attrs, $value): string {
 		if ($field["type"] == "enum") {
-			return (isset($_GET["select"]) ? "<label><input type='radio'$attrs value='-1' checked><i>" . lang('original') . "</i></label> " : "")
-				. ($field["null"] ? "<label><input type='radio'$attrs value=''" . ($value !== null || isset($_GET["select"]) ? "" : " checked") . "><i>NULL</i></label> " : "")
-				. enum_input("radio", $attrs, $field, $value, $value === 0 ? 0 : null) // 0 - empty value
+			return (isset($_GET["select"]) ? "<label><input type='radio'$attrs value='orig' checked><i>" . lang('original') . "</i></label> " : "")
+				. enum_input("radio", $attrs, $field, $value, "NULL")
 			;
 		}
 		return "";
@@ -750,7 +754,7 @@ class Adminer {
 		} elseif (preg_match('~^([+-]|\|\|)$~', $function)) {
 			$return = idf_escape($name) . " $function $return";
 		} elseif (preg_match('~^[+-] interval$~', $function)) {
-			$return = idf_escape($name) . " $function " . (preg_match("~^(\\d+|'[0-9.: -]') [A-Z_]+\$~i", $value) ? $value : $return);
+			$return = idf_escape($name) . " $function " . (preg_match("~^(\\d+|'[0-9.: -]') [A-Z_]+\$~i", $value) && JUSH != "pgsql" ? $value : $return);
 		} elseif (preg_match('~^(addtime|subtime|concat)$~', $function)) {
 			$return = "$function(" . idf_escape($name) . ", $return)";
 		} elseif (preg_match('~^(md5|sha1|password|encrypt)$~', $function)) {
@@ -839,7 +843,7 @@ class Adminer {
 					}
 				}
 			}
-			$result = connection()->query($query, 1); // 1 - MYSQLI_USE_RESULT //! enum and set as numbers
+			$result = connection()->query($query, 1); // 1 - MYSQLI_USE_RESULT
 			if ($result) {
 				$insert = "";
 				$buffer = "";
@@ -915,7 +919,7 @@ class Adminer {
 	* @return string filename without extension
 	*/
 	function dumpFilename(string $identifier): string {
-		return friendly_url($identifier != "" ? $identifier : (SERVER != "" ? SERVER : "localhost"));
+		return friendly_url($identifier != "" ? $identifier : (SERVER ?: "localhost"));
 	}
 
 	/** Send headers for export
@@ -962,6 +966,12 @@ class Adminer {
 		echo (support("scheme") ? "<a href='" . h(ME) . "scheme='>" . ($_GET["ns"] != "" ? lang('Alter schema') : lang('Create schema')) . "</a>\n" : "");
 		echo ($_GET["ns"] !== "" ? '<a href="' . h(ME) . 'schema=">' . lang('Database schema') . "</a>\n" : "");
 		echo (support("privileges") ? "<a href='" . h(ME) . "privileges='>" . lang('Privileges') . "</a>\n" : "");
+		if ($_GET["ns"] !== "") {
+			echo (support("routine") ? "<a href='#routines'>" . lang('Routines') . "</a>\n" : "");
+			echo (support("sequence") ? "<a href='#sequences'>" . lang('Sequences') . "</a>\n" : "");
+			echo (support("type") ? "<a href='#user-types'>" . lang('User types') . "</a>\n" : "");
+			echo (support("event") ? "<a href='#events'>" . lang('Events') . "</a>\n" : "");
+		}
 		return true;
 	}
 
@@ -984,7 +994,7 @@ class Adminer {
 						if ($password !== null) {
 							$dbs = $_SESSION["db"][$vendor][$server][$username];
 							foreach (($dbs ? array_keys($dbs) : array("")) as $db) {
-								$output .= "<li><a href='" . h(auth_url($vendor, $server, $username, $db)) . "'>($name) " . h($username . ($server != "" ? "@" . adminer()->serverName($server) : "") . ($db != "" ? " - $db" : "")) . "</a>\n";
+								$output .= "<li><a href='" . h(auth_url($vendor, $server, $username, $db)) . "'>($name) " . h("$username@" . ($server != "" ? adminer()->serverName($server) : "") . ($db != "" ? " - $db" : "")) . "</a>\n";
 							}
 						}
 					}
@@ -1042,7 +1052,15 @@ class Adminer {
 				foreach ($tables as $table => $type) {
 					$links[] = preg_quote($table, '/');
 				}
-				echo "var jushLinks = { " . JUSH . ": [ '" . js_escape(ME) . (support("table") ? "table=" : "select=") . "\$&', /\\b(" . implode("|", $links) . ")\\b/g ] };\n";
+				echo "var jushLinks = { " . JUSH . ":";
+				json_row(js_escape(ME) . (support("table") ? "table" : "select") . '=$&', '/\b(' . implode('|', $links) . ')\b/g', false);
+				if (support('routine')) {
+					foreach (routines() as $row) {
+						json_row(js_escape(ME) . 'function=' . urlencode($row["SPECIFIC_NAME"]) . '&name=$&', '/\b' . preg_quote($row["ROUTINE_NAME"], '/') . '(?=["`]?\()/g', false);
+					}
+				}
+				json_row('');
+				echo "};\n";
 				foreach (array("bac", "bra", "sqlite_quo", "mssql_bra") as $val) {
 					echo "jushLinks.$val = jushLinks." . JUSH . ";\n";
 				}
@@ -1100,7 +1118,7 @@ class Adminer {
 		foreach ($tables as $table => $status) {
 			$table = "$table"; // do not highlight "0" as active everywhere
 			$name = adminer()->tableName($status);
-			if ($name != "" && !$status["inherited"]) {
+			if ($name != "" && !$status["partition"]) {
 				echo '<li><a href="' . h(ME) . 'select=' . urlencode($table) . '"'
 					. bold($_GET["select"] == $table || $_GET["edit"] == $table, "select")
 					. " title='" . lang('Select data') . "'>" . lang('select') . "</a> "
@@ -1115,4 +1133,19 @@ class Adminer {
 		}
 		echo "</ul>\n";
 	}
+
+	/** Get process list
+	* @return list<string[]> [$row]
+	*/
+	function processList(): array {
+		return process_list();
+	}
+
+	/** Kill a process
+	* @param numeric-string $id
+	* @return Result|bool
+	*/
+	function killProcess(string $id) {
+		return kill_process($id);
+	}
 }
