@@ -91,8 +91,8 @@ Adminer::$instance =
 include "../adminer/drivers/mysql.inc.php"; // must be included as last driver
 
 define('Adminer\JUSH', Driver::$jush);
-define('Adminer\SERVER', $_GET[DRIVER]); // read from pgsql=localhost, '' means default server, null means no server
-define('Adminer\DB', $_GET["db"]); // for the sake of speed and size
+define('Adminer\SERVER', "" . $_GET[DRIVER]); // read from pgsql=localhost, '' means default server
+define('Adminer\DB', "$_GET[db]"); // for the sake of speed and size
 define(
 	'Adminer\ME',
 	preg_replace('~\?.*~', '', relative_uri()) . '?'
@@ -108,3 +108,5 @@ include "../adminer/include/xxtea.inc.php";
 include "../adminer/include/auth.inc.php";
 include "./include/editing.inc.php";
 include "./include/connect.inc.php";
+
+adminer()->afterConnect();
