@@ -34,7 +34,7 @@ abstract class SqlDriver {
 	/** Connect to the database
 	* @return Db|string string for error
 	*/
-	static function connect(?string $server, string $username, string $password) {
+	static function connect(string $server, string $username, string $password) {
 		$connection = new Db;
 		return ($connection->attach($server, $username, $password) ?: $connection);
 	}
@@ -189,11 +189,6 @@ abstract class SqlDriver {
 		return $idf;
 	}
 
-	/** Convert operator so it can be used in search */
-	function convertOperator(string $operator): string {
-		return $operator;
-	}
-
 	/** Convert value returned by database to actual value
 	* @param Field $field
 	*/
@@ -258,8 +253,7 @@ abstract class SqlDriver {
 		return !is_view($table_status);
 	}
 
-	/**
-	 * Return list of supported index algorithms, first one is default
+	/** Return list of supported index algorithms, first one is default
 	 * @param TableStatus $tableStatus
 	 * @return list<string>
 	 */
@@ -281,7 +275,7 @@ AND CHECK_CLAUSE NOT LIKE '% IS NOT NULL'", $this->conn); // ignore default IS N
 	}
 
 	/** Get all fields in the current schema
-	* @return array<list<array{field:string, null:bool, type:string, length:?numeric-string, primary?:numeric-string}>>
+	* @return array<list<array{field:string, null:bool, type:string, length:?numeric-string}>> optionally also 'primary'
 	*/
 	function allFields(): array {
 		$return = array();
