@@ -72,6 +72,10 @@ function print_select_result($result, ?Db $connection2 = null, array $orgtables
 				} else {
 					$link = ME . "edit=" . urlencode($links[$key]);
 					foreach ($indexes[$links[$key]] as $col => $j) {
+						if ($row[$j] === null) {
+							$link = "";
+							break;
+						}
 						$link .= "&where" . urlencode("[" . bracket_escape($col) . "]") . "=" . urlencode($row[$j]);
 					}
 				}
@@ -150,13 +154,13 @@ function select_input(string $attrs, array $options, ?string $value = "", string
 * @param string $key or "" to close the object
 * @param string|int $val
 */
-function json_row(string $key, $val = null): void {
+function json_row(string $key, $val = null, bool $escape = true): void {
 	static $first = true;
 	if ($first) {
 		echo "{";
 	}
 	if ($key != "") {
-		echo ($first ? "" : ",") . "\n\t\"" . addcslashes($key, "\r\n\t\"\\/") . '": ' . ($val !== null ? '"' . addcslashes($val, "\r\n\"\\/") . '"' : 'null');
+		echo ($first ? "" : ",") . "\n\t\"" . addcslashes($key, "\r\n\t\"\\/") . '": ' . ($val !== null ? ($escape ? '"' . addcslashes($val, "\r\n\"\\/") . '"' : $val) : 'null');
 		$first = false;
 	} else {
 		echo "\n}\n";
@@ -201,20 +205,6 @@ function edit_type(string $key, array $field, array $collations, array $foreign_
 	);
 }
 
-/** Get partition info
-* @return array{partition_by:string, partition:string, partitions:string, partition_names:list<string>, partition_values:list<string>}
-*/
-function get_partitions_info(string $table): array {
-	$from = "FROM information_schema.PARTITIONS WHERE TABLE_SCHEMA = " . q(DB) . " AND TABLE_NAME = " . q($table);
-	$result = connection()->query("SELECT PARTITION_METHOD, PARTITION_EXPRESSION, PARTITION_ORDINAL_POSITION $from ORDER BY PARTITION_ORDINAL_POSITION DESC LIMIT 1");
-	$return = array();
-	list($return["partition_by"], $return["partition"], $return["partitions"]) = $result->fetch_row();
-	$partitions = get_key_vals("SELECT PARTITION_NAME, PARTITION_DESCRIPTION $from AND PARTITION_NAME != '' ORDER BY PARTITION_ORDINAL_POSITION");
-	$return["partition_names"] = array_keys($partitions);
-	$return["partition_values"] = array_values($partitions);
-	return $return;
-}
-
 /** Filter length value including enums */
 function process_length(?string $length): string {
 	$enum_length = driver()->enumLength;
@@ -328,7 +318,7 @@ function edit_fields(array $fields, array $collations, $type = "TABLE", array $f
 		echo "<tr" . ($display ? "" : " style='display: none;'") . ">\n";
 		echo ($type == "PROCEDURE" ? "<td>" . html_select("fields[$i][inout]", explode("|", driver()->inout), $field["inout"]) : "") . "<th>";
 		if ($display) {
-			echo "<input name='fields[$i][field]' value='" . h($field["field"]) . "' data-maxlength='64' autocapitalize='off' aria-labelledby='label-name'>";
+			echo "<input name='fields[$i][field]' value='" . h($field["field"]) . "' data-maxlength='64' autocapitalize='off' aria-labelledby='label-name'" . (isset($_POST["add"][$i-1]) ? " autofocus" : "") . ">";
 		}
 		echo input_hidden("fields[$i][orig]", $orig);
 		edit_type("fields[$i]", $field, $collations, $foreign_keys);
@@ -521,20 +511,6 @@ function tar_file(string $filename, $tmp_file): void {
 	echo str_repeat("\0", 511 - ($tmp_file->size + 511) % 512);
 }
 
-/** Get INI bytes value */
-function ini_bytes(string $ini): int {
-	$val = ini_get($ini);
-	switch (strtolower(substr($val, -1))) {
-		case 'g':
-			$val = (int) $val * 1024; // no break
-		case 'm':
-			$val = (int) $val * 1024; // no break
-		case 'k':
-			$val = (int) $val * 1024;
-	}
-	return $val;
-}
-
 /** Create link to database documentation
 * @param string[] $paths JUSH => $path
 * @param string $text HTML code
