@@ -259,6 +259,56 @@ Lang::$translations = array(
 	'Permanent link' => 'স্থায়ী লিংক',
 	'Edit all' => 'সবগুলো সম্পাদনা করুন',
 	'HH:MM:SS' => 'HH:MM:SS',
+	'Check has been dropped.' => 'চেক ড্রপ করা হয়েছে।',
+	'Check has been altered.' => 'চেক পরিবর্তন করা হয়েছে।',
+	'Check has been created.' => 'চেক তৈরি করা হয়েছে।',
+	'Alter check' => 'চেক পরিবর্তন করুন',
+	'Create check' => 'চেক তৈরি করুন',
+	'Drop %s?' => '%s ড্রপ করবেন?',
+	'Tables have been optimized.' => 'টেবিলগুলি অপ্টিমাইজ করা হয়েছে।',
+	'Materialized view' => 'মেটেরিয়ালাইজড ভিউ',
+	'Vacuum' => 'ভ্যাকুয়াম',
+	'Selected' => 'নির্বাচিত',
+	'overwrite' => 'ওভাররাইট',
+	'DB' => 'ডিবি',
+	'Algorithm' => 'অ্যালগরিদম',
+	'Columns' => 'কলাম',
+	'Ctrl+click on a value to modify it.' => 'একটি মান পরিবর্তন করতে Ctrl+ক্লিক করুন।',
+	'File must be in UTF-8 encoding.' => 'ফাইলটি UTF-8 এনকোডিংয়ে হতে হবে।',
+	'Modify' => 'পরিবর্তন করুন',
+	'Load more data' => 'আরও ডেটা লোড করুন',
+	'Loading' => 'লোড হচ্ছে',
+	'ATTACH queries are not supported.' => 'ATTACH কোয়েরি সমর্থিত নয়।',
+	'Warnings' => 'সতর্কতা',
+	'%d / ' => array('%d / '),
+	'Limit rows' => 'সারি সীমিত করুন',
+	'Inherits from' => 'থেকে উত্তরাধিকারসূত্রে প্রাপ্ত',
+	'Checks' => 'চেকস',
+	'Adminer does not support accessing a database without a password, <a href="https://www.adminer.org/en/password/"%s>more information</a>.' => 'Adminer পাসওয়ার্ড ছাড়া ডাটাবেস অ্যাক্সেস সমর্থন করে না, <a href="https://www.adminer.org/en/password/"%s>আরও তথ্য</a>।',
+	'Default value' => 'ডিফল্ট মান',
+	'Full table scan' => 'সম্পূর্ণ টেবিল স্ক্যান',
+	'Too many unsuccessful logins, try again in %d minute(s).' => array('অনেকগুলি ব্যর্থ লগইন প্রচেষ্টা, %d মিনিট পরে আবার চেষ্টা করুন।'),
+	'Thanks for using Adminer, consider <a href="https://www.adminer.org/en/donation/">donating</a>.' => 'Adminer ব্যবহার করার জন্য ধন্যবাদ, <a href="https://www.adminer.org/en/donation/">দান করার</a> কথা বিবেচনা করুন।',
+	'Master password expired. <a href="https://www.adminer.org/en/extension/"%s>Implement</a> %s method to make it permanent.' => 'মাস্টার পাসওয়ার্ডের মেয়াদ শেষ হয়েছে। এটিকে স্থায়ী করতে <a href="https://www.adminer.org/en/extension/"%s>ইমপ্লিমেন্ট</a> %s মেথড।',
+	'The action will be performed after successful login with the same credentials.' => 'একই ক্রেডেনশিয়ালস দিয়ে সফলভাবে লগইন করার পরে এই কর্মটি সম্পাদন করা হবে।',
+	'Connecting to privileged ports is not allowed.' => 'প্রিভিলেজড পোর্টে সংযোগ করা অনুমোদিত নয়।',
+	'There is a space in the input password which might be the cause.' => 'ইনপুট পাসওয়ার্ডে একটি স্পেস রয়েছে যা এর কারণ হতে পারে।',
+	'If you did not send this request from Adminer then close this page.' => 'আপনি যদি Adminer থেকে এই অনুরোধ না করে থাকেন তবে এই পৃষ্ঠাটি বন্ধ করুন।',
+	'You can upload a big SQL file via FTP and import it from server.' => 'আপনি FTP এর মাধ্যমে একটি বড় SQL ফাইল আপলোড করতে পারেন এবং সার্ভার থেকে এটি ইম্পোর্ট করতে পারেন।',
+	'Size' => 'আকার',
+	'Compute' => 'কম্পিউট',
+	'Loaded plugins' => 'লোড করা প্লাগইনগুলি',
+	'screenshot' => 'স্ক্রিনশট',
+	'You are offline.' => 'আপনি অফলাইনে আছেন।',
+	'You have no privileges to update this table.' => 'এই টেবিল আপডেট করার জন্য আপনার কোন অনুমতি নেই।',
+	'Saving' => 'সংরক্ষণ করা হচ্ছে',
+	'Unknown error.' => 'অজানা ত্রুটি।',
+	'%s must <a%s>return an array</a>.' => '%s অবশ্যই <a%s>একটি অ্যারে রিটার্ন করতে হবে</a>।',
+	'<a%s>Configure</a> %s in %s.' => '<a%s>কনফিগার করুন</a> %s এ %s।',
+	'Disable %s or enable %s or %s extensions.' => '%s নিষ্ক্রিয় করুন অথবা %s বা %s এক্সটেনশন সক্রিয় করুন।',
+	'Database does not support password.' => 'ডাটাবেস পাসওয়ার্ড সমর্থন করে না।',
+	'yes' => 'হ্যাঁ',
+	'no' => 'না',
 );
 
 // run `php ../../lang.php bn` to update this file
