@@ -27,7 +27,7 @@ Lang::$translations = array(
 	'Connecting to privileged ports is not allowed.' => 'Připojování k privilegovaným portům není povoleno.',
 	'Disable %s or enable %s or %s extensions.' => 'Zakažte %s nebo povolte rozšíření %s nebo %s.',
 	'Session support must be enabled.' => 'Session proměnné musí být povolené.',
-	'Session expired, please login again.' => 'Session vypršela, přihlašte se prosím znovu.',
+	'Session expired, please login again.' => 'Session vypršela, přihlaste se prosím znovu.',
 	'The action will be performed after successful login with the same credentials.' => 'Akce bude provedena po úspěšném přihlášení se stejnými přihlašovacími údaji.',
 	'%s version: %s through PHP extension %s' => 'Verze %s: %s přes PHP rozšíření %s',
 	'Refresh' => 'Obnovit',
@@ -76,6 +76,7 @@ Lang::$translations = array(
 	'Webserver file %s' => 'Soubor %s na webovém serveru',
 	'Run file' => 'Spustit soubor',
 	'File does not exist.' => 'Soubor neexistuje.',
+	'Increase %s.' => 'Zvyšte %s.',
 	'File uploads are disabled.' => 'Nahrávání souborů není povoleno.',
 	'Unable to upload a file.' => 'Nepodařilo se nahrát soubor.',
 	'Maximum allowed file size is %sB.' => 'Maximální povolená velikost souboru je %sB.',
@@ -195,6 +196,7 @@ Lang::$translations = array(
 	'Partition name' => 'Název oddílu',
 	'Values' => 'Hodnoty',
 	'Inherits from' => 'Zděděná z',
+	'Inherited by' => 'Zděděné',
 
 	'View' => 'Pohled',
 	'Materialized view' => 'Materializovaný pohled',
