@@ -662,24 +662,29 @@ function indexesAddColumn(prefix) {
 * @param string
 */
 function sqlSubmit(form, root) {
-	if (encodeURIComponent(form['query'].value).length < 500) {
-		form.action = root
-			+ '&sql=' + encodeURIComponent(form['query'].value)
-			+ (form['limit'].value ? '&limit=' + +form['limit'].value : '')
-			+ (form['error_stops'].checked ? '&error_stops=1' : '')
-			+ (form['only_errors'].checked ? '&only_errors=1' : '')
-		;
+	const action = root
+		+ '&sql=' + encodeURIComponent(form['query'].value)
+		+ (form['limit'].value ? '&limit=' + +form['limit'].value : '')
+		+ (form['error_stops'].checked ? '&error_stops=1' : '')
+		+ (form['only_errors'].checked ? '&only_errors=1' : '')
+	;
+	if ((document.location.origin + document.location.pathname + action).length < 2000) { // reasonable minimum is 2048
+		form.action = action;
 	}
 }
 
 /** Check if PHP can handle the uploaded files
+* @param Event
+* @param number
+* @param string
 * @param number
 * @param string
-* @param Event
 */
-function fileChange(event, maxFileUploads, message) {
-	if (event.target.files.length > maxFileUploads) {
-		alert(message);
+function fileChange(event, count, countMessage, size, sizeMessage) {
+	if (event.target.files.length > count) {
+		alert(countMessage);
+	} else if (Array.from(event.target.files).reduce((sum, file) => sum + file.size, 0) > size) {
+		alert(sizeMessage);
 	}
 }
 
