@@ -59,6 +59,9 @@ class Adminer {
 		return 5;
 	}
 
+	function afterConnect() {
+	}
+
 	function headers() {
 	}
 
@@ -214,9 +217,9 @@ ORDER BY ORDINAL_POSITION", null, "") as $row
 	}
 
 	function selectVal($val, $link, $field, $original) {
-		$return = $val;
+		$return = "$val";
 		$link = h($link);
-		if (preg_match('~blob|bytea~', $field["type"]) && !is_utf8($val)) {
+		if (is_blob($field) && !is_utf8($val)) {
 			$return = lang('%d byte(s)', strlen($original));
 			if (preg_match("~^(GIF|\xFF\xD8\xFF|\x89PNG\x0D\x0A\x1A\x0A)~", $original)) { // GIF|JPG|PNG, getimagetype() works with filename
 				$return = "<img src='$link' alt='$return'>";
@@ -261,14 +264,14 @@ ORDER BY ORDINAL_POSITION", null, "") as $row
 		$fields = fields($_GET["select"]);
 		foreach ($columns as $name => $desc) {
 			$field = $fields[$name];
-			if (preg_match("~enum~", $field["type"]) || like_bool($field)) { //! set - uses 1 << $i and FIND_IN_SET()
+			if ($field["type"] == "enum" || like_bool($field)) { //! set - uses 1 << $i and FIND_IN_SET()
 				$key = $keys[$name];
 				$i--;
 				echo "<div>" . h($desc) . ":" . input_hidden("where[$i][col]", $name);
 				$val = idx($where[$key], "val");
 				echo (like_bool($field)
 					? "<select name='where[$i][val]'>" . optionlist(array("" => "", lang('no'), lang('yes')), $val, true) . "</select>"
-					: enum_input("checkbox", " name='where[$i][val][]'", $field, (array) $val, ($field["null"] ? 0 : null))
+					: enum_input("checkbox", " name='where[$i][val][]'", $field, (array) $val, lang('empty'))
 				);
 				echo "</div>\n";
 				unset($columns[$name]);
@@ -366,7 +369,13 @@ ORDER BY ORDINAL_POSITION", null, "") as $row
 					if ($col != "" || is_numeric($val) || !preg_match(number_type(), $field["type"])) {
 						$name = idf_escape($name);
 						if ($col != "" && $field["type"] == "enum") {
-							$conds[] = (in_array(0, $val) ? "$name IS NULL OR " : "") . "$name IN (" . implode(", ", array_map('Adminer\q', $val)) . ")";
+							$in = array();
+							foreach ($val as $val1) {
+								if (preg_match('~val-~', $val1)) {
+									$in[] = q(substr($val1, 4));
+								}
+							}
+							$conds[] = (in_array("null", $val) ? "$name IS NULL OR " : "") . ($in ? "$name IN (" . implode(", ", $in) . ")" : "0");
 						} else {
 							$text_type = preg_match('~char|text|enum|set~', $field["type"]);
 							$value = adminer()->processInput($field, (!$op && $text_type && preg_match('~^[^%]+$~', $val) ? "%$val%" : $val));
@@ -456,8 +465,8 @@ ORDER BY ORDINAL_POSITION", null, "") as $row
 
 	function editInput($table, $field, $attrs, $value) {
 		if ($field["type"] == "enum") {
-			return (isset($_GET["select"]) ? "<label><input type='radio'$attrs value='-1' checked><i>" . lang('original') . "</i></label> " : "")
-				. enum_input("radio", $attrs, $field, ($value || isset($_GET["select"]) ? $value : ""), ($field["null"] ? "" : null))
+			return (isset($_GET["select"]) ? "<label><input type='radio'$attrs value='orig' checked><i>" . lang('original') . "</i></label> " : "")
+				. enum_input("radio", $attrs, $field, $value, lang('empty'))
 			;
 		}
 		$options = $this->foreignKeyOptions($table, $field["field"], $value);
