@@ -12,7 +12,7 @@ class AdminerLoginPasswordLess extends Adminer\Plugin {
 	/** Set allowed password
 	* @param string $password_hash result of password_hash()
 	*/
-	function __construct(string $password_hash) {
+	function __construct($password_hash) {
 		$this->password_hash = $password_hash;
 	}
 
